@@ -22,14 +22,14 @@ func (a *Annotator) UnmarshalJSON(data []byte) error {
 	annotatorStr := string(data)
 	annotatorStr = strings.Trim(annotatorStr, "\"")
 
-	annotatorFields := strings.SplitN(annotatorStr, ": ", 2)
+	annotatorFields := strings.SplitN(annotatorStr, ":", 2)
 
 	if len(annotatorFields) != 2 {
 		return fmt.Errorf("failed to parse Annotator '%s'", annotatorStr)
 	}
 
-	a.AnnotatorType = annotatorFields[0]
-	a.Annotator = annotatorFields[1]
+	a.AnnotatorType = strings.TrimSpace(annotatorFields[0])
+	a.Annotator = strings.TrimSpace(annotatorFields[1])
 
 	return nil
 }
